@@ -4,9 +4,10 @@ use 5.008_001;
 use strict;
 #use warnings;
 
-our $VERSION = '0.50';
+our $VERSION = '0.51';
 
-use Exporter qw(import);
+use Exporter;
+our @ISA = qw(Exporter);
 
 our $TESTING_PERL_ONLY;
 $TESTING_PERL_ONLY = $ENV{DATA_UTIL_PUREPERL} ? 1 : 0
@@ -28,11 +29,11 @@ require 'Data/Util/PurePerl.pm' # not to create the namespace
 	if $TESTING_PERL_ONLY;
 
 our @EXPORT_OK = qw(
-	is_scalar_ref is_array_ref is_hash_ref is_code_ref is_glob_ref is_regex_ref
+	is_scalar_ref is_array_ref is_hash_ref is_code_ref is_glob_ref is_rx is_regex_ref
 	is_instance is_invocant
 	is_value is_string is_number is_integer
 
-	scalar_ref array_ref hash_ref code_ref glob_ref regex_ref
+	scalar_ref array_ref hash_ref code_ref glob_ref rx regex_ref
 	instance invocant
 
 	anon_scalar neat
@@ -57,12 +58,15 @@ our %EXPORT_TAGS = (
 
 	check   => [qw(
 		is_scalar_ref is_array_ref is_hash_ref is_code_ref
-		is_glob_ref is_regex_ref is_instance is_invocant
+		is_glob_ref is_rx is_instance is_invocant
 		is_value is_string is_number is_integer
+
+		is_regex_ref
 	)],
 	validate  => [qw(
 		scalar_ref array_ref hash_ref code_ref
-		glob_ref regex_ref instance invocant
+		glob_ref rx instance invocant
+		regex_ref
 	)],
 );
 
@@ -75,7 +79,7 @@ Data::Util - A selection of utilities for data and data types
 
 =head1 VERSION
 
-This document describes Data::Util version 0.50
+This document describes Data::Util version 0.51
 
 =head1 SYNOPSIS
 
@@ -88,7 +92,7 @@ This document describes Data::Util version 0.50
 		my $href = hash_ref(shift);
 		my $cref = code_ref(shift);
 		my $gref = glob_ref(shift);
-		my $rref = regex_ref(shift);
+		my $rx   = rx(shift); # regular expression
 		my $obj  = instance(shift, 'Foo');
 		# ...
 	}
@@ -110,7 +114,7 @@ This document describes Data::Util version 0.50
 	# miscelaneous
 	use Data::Util qw(:all);
 
-	my $ref_to_undef = anon_scalar();
+	my $x = anon_scalar();
 	$x = anon_scalar($x); # OK
 
 	my $stash = get_stash('Foo');
@@ -124,7 +128,7 @@ This document describes Data::Util version 0.50
 
 	my($pkg, $name) = get_code_info(\&Foo::hello); # => ('Foo', 'hello')
 	my $fqn         = get_code_info(\&Foo::hello); # =>  'Foo::hello'
-	my $code        = get_code_ref($fqn);          # => \&Foo::hello
+	my $code        = get_code_ref('Foo::hello');  # => \&Foo::hello
 
 	uninstall_subroutine('Foo', qw(hello goodby));
 
@@ -141,7 +145,7 @@ The implementation of this module is both Pure Perl and XS, so if you have a C
 compiler, all the functions this module provides are really faster.
 
 
-There are many benchmakrs in F<DIST-DIR/benchmark/> directory.
+There are many benchmarks in F<DIST-DIR/benchmark/> directory.
 
 =head1 INTERFACE
 
@@ -174,7 +178,7 @@ For a CODE reference.
 
 For a GLOB reference.
 
-=item is_regex_ref(value)
+=item is_rx(value)
 
 For a regular expression reference generated by the C<qr//> operator.
 
@@ -201,19 +205,21 @@ This function has no counterpart for validation.
 =item is_string(value)
 
 Checks whether I<value> is a string with non-zero-length contents,
-equivatent to C<< is_value($value) && length($value) > 0 >>.
+equivalent to C<< is_value($value) && length($value) > 0 >>.
 
 This function has no counterpart for validation.
 
 =item is_number(value)
 
 Checks whether I<value> is a number.
-Here, a B<number> means that the perl parser is understandable and that
-the numifying process like C<< sprintf '%g', $value >> produces no warnings.
+Here, a B<number> means that the perl parser can understand it and that
+the perl numeric converter (e.g. invoked by C<< sprintf '%g', $value >>)
+doesn't complain about it.
 
 It is similar to C<Scalar::Util::looks_like_number()>
-but refuses C<"Inf">, C<"NaN">. Note that C<9**9**9> makes C<infinity> and
-C<9**9**9 - 9**9**9> makes C<not a number>.
+but refuses C<infinity>, C<not a number> and C<"0 but true">.
+Note that C<9**9**9> makes C<infinity> and C<9**9**9 - 9**9**9> makes
+C<not a number>.
 
 This function has no counterpart for validation.
 
@@ -258,7 +264,7 @@ For a CODE reference.
 
 For a GLOB reference.
 
-=item regex_ref(value)
+=item rx(value)
 
 For a regular expression reference.
 
@@ -375,8 +381,8 @@ qualified name in scalar context.
 
 Returns I<&package::name> if it exists, not touching the symbol in the stash.
 
-if I<flag> is a string C<-create>, it returns I<&package::name> regardles of
-its existance. That is, it is equivalent to
+if I<flag> is a string C<-create>, it returns I<&package::name> regardless of
+its existence. That is, it is equivalent to
 C<< do{ no strict 'refs'; \&{package . '::' . $name} } >>.
 
 For example:
@@ -497,7 +503,7 @@ Goro Fuji(gfx) E<lt>gfuji(at)cpan.orgE<gt>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2008, Goro Fuji E<lt>gfuji(at)cpan.orgE<gt>. Some rights reserved.
+Copyright (c) 2008-2009, Goro Fuji E<lt>gfuji(at)cpan.orgE<gt>. Some rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
